package com.jay.monitor.data.server.store.mysql;

import com.cat.file.message.MessageManagerProcess;
import com.cat.file.message.internal.DefaultMessageTree;
import com.cat.file.message.internal.MessageTree;
import com.jay.monitor.data.core.enums.MsgTypeEnums;
import com.jay.monitor.data.core.model.serializable.URLDataDTO;
import com.jay.monitor.data.server.daos.JayMonitorUrlMapperExt;
import com.jay.monitor.data.server.enums.StoreType;
import com.jay.monitor.data.server.models.entity.JayMonitorUrl;
import com.jay.monitor.data.server.store.AbstractStoreProcess;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * @Module 执行器
 * @Description Mysql的URL请求类型处理器
 * @Author liukaixiong
 * @Date 2020/10/29 13:36
 */
@Component
@Lazy
public class MysqlUrlStoreProcess extends AbstractStoreProcess<URLDataDTO, JayMonitorUrl> {

    private Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    @Qualifier("jayMonitorUrlMapperExt")
    private JayMonitorUrlMapperExt urlMapper;

    @Autowired
    private MessageManagerProcess messageManagerProcess;

    @Override
    public StoreType storeType() {
        return StoreType.MYSQL;
    }

    @Override
    public MsgTypeEnums msgTypeEnums() {
        return MsgTypeEnums.URL;
    }

    @Override
    public String tableName() {
        return "jay_monitor_url";
    }

    @Override
    public String searchContentById(String date, String id) throws Exception {
        JayMonitorUrl monitorData = urlMapper.selectPartitionById(date, Integer.valueOf(id));
        MessageTree messageTree = new DefaultMessageTree(monitorData.getApplicationName(), monitorData.getApplicationIp(), monitorData.getId(), monitorData.getCreatedTime(), null);
        String messageId = messageTree.getMessageId();
        return this.messageManagerProcess.getMessage(messageId);
    }

    @Override
    public void speedUpConsumerList(List<URLDataDTO> requestList) {
        List<JayMonitorUrl> monitorList = new ArrayList<>();
        for (int i = 0; i < requestList.size(); i++) {

            URLDataDTO request = requestList.get(i);
            String url = request.getUrl();
            if (StringUtils.isNotEmpty(request.getUrl())) {
                url = url.replaceAll("//", "/");
            }

            JayMonitorUrl monitorUrl = new JayMonitorUrl();
            BeanUtils.copyProperties(request, monitorUrl);
            monitorUrl.setUrl(url);
            monitorUrl.setApplicationName(request.getApplicationName());
            monitorUrl.setApplicationIp(request.getIp());
            monitorUrl.setCreatedTime(request.getCreateDate());
            monitorUrl.setDataGroupName(request.getGroupName());
            monitorUrl.setDataGroupKey(request.getGroupKeyName());
            monitorUrl.setDataId(request.getDataId());
            monitorUrl.setClientIp(request.getClientIp());
            monitorUrl.setUserId(request.getUserId());
            if (request.getRequestTime() != null) {
                monitorUrl.setRequestTime(request.getRequestTime().intValue());
            }
            monitorList.add(monitorUrl);
        }

        urlMapper.batchPartitionInsert(getPartitionId(), monitorList);

        for (int i = 0; i < monitorList.size(); i++) {
            Integer id = monitorList.get(i).getId();
            URLDataDTO dataDTO = requestList.get(i);
            MessageTree messageTree = new DefaultMessageTree(dataDTO.getApplicationName(), dataDTO.getIp(), id, dataDTO.getCreateDate(), dataDTO.getJsonContent());
            this.messageManagerProcess.insert(messageTree);
            logger.debug("添加成功:" + messageTree.getMessageId());
        }
    }

    @Override
    public List<JayMonitorUrl> searchDataByList(String date, Integer pageSize, JayMonitorUrl entity) throws Exception {
        return urlMapper.selectPartitionByList(date, pageSize, entity);
    }
}
